Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(166)

Unified Diff: content/public/browser/gpu_service_registry.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/content_browser_client.h ('k') | content/public/browser/gpu_service_registry.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/gpu_service_registry.h
diff --git a/content/public/browser/gpu_service_registry.h b/content/public/browser/gpu_service_registry.h
index 6f041807ea436fd228a52403192153b580218b81..e1455f3dab4e81d6f283fc907310d0777aaca5bf 100644
--- a/content/public/browser/gpu_service_registry.h
+++ b/content/public/browser/gpu_service_registry.h
@@ -7,16 +7,17 @@
#include "content/common/content_export.h"
-namespace shell {
+namespace service_manager {
class InterfaceProvider;
}
namespace content {
// Get shell::InterfaceProvider that can be used to bind interfaces registered
// via ContentGpuClient::ExposeInterfacesToBrowser().
// This must be called on IO thread.
-CONTENT_EXPORT shell::InterfaceProvider* GetGpuRemoteInterfaces();
+CONTENT_EXPORT service_manager::InterfaceProvider* GetGpuRemoteInterfaces();
} // namespace content
« no previous file with comments | « content/public/browser/content_browser_client.h ('k') | content/public/browser/gpu_service_registry.cc » ('j') | no next file with comments »
@@ -7,16 +7,17 @@
}
namespace content {
-// Get shell::InterfaceProvider that can be used to bind interfaces registered
+// Get service_manager::InterfaceProvider that can be used to bind interfaces
+// registered
// via ContentGpuClient::ExposeInterfacesToBrowser().
// This must be called on IO thread.

Powered by Google App Engine
This is Rietveld 408576698